% OVERVIEW:
% This is a stereophotogrammetric quality control check function developed by K.Scott, as described in Scott et al., 2021
% This function compiles the processing required to complete the quality control check as explained in the material and methods of this paper.
% To ensure easy adoption to different labs and calibration objects, the functions have been refined to allow for easy adaption. Please read the comment notes in the script to do this.
% This function has been created for adaption and therefore editing is allowed based on the FigShare MIT License agreement. 


% DISCLAIMER:
% Current script relies on the open-source C3D reader, Biomechanical ToolKit. 
% Reference DOI: http://dx.doi.org/10.1016/j.cmpb.2014.01.012.
% PLEASE ENSURE TO DOWNLOAD THIS TOOLKIT PRIOR TO USE OR AMEND CODE TO FIT PREFFERED C3D READER. Link to BTK download: https://code.google.com/archive/p/b-tk/


% REFERENCE TO METHODOLOGY:
% Scott, K.; Bonci, T.; Alcock, L.; Buckley, E.; Hansen, C.; Gazit, E.; Schwickert, L.; Cereatti, A.; Mazzà, C.; on behalf of the Mobilise-D Consortium. A Quality Control Check to Ensure Comparability of Stereophotogrammetric Data between Session and Systems. Sensors 2021, 21, 8223. https://doi.org/10.3390/s21248223


% AUTHOR DETAILS:
% Author: K Scott
% Affiliation: Department of Mechanical Engineering, The University of Sheffiled
% Email of Author: KScott3@sheffield.ac.uk


% VERSION DETAILS:
% Version: 1.1
% Date Completed: 9/12/2021



%_________________________________________________________________________%


function Scott_SP_Quality_Control_Check

  %% PREDEFINE FILENAMES ==================================================
  % Please amend finlename tags to suit the filenames you have selected. 
  
  StaticTrial_Filename = 'Static';
  DynamicTrial_Filename = 'Dynamic';
  
  
  %% DEFINE INTER-MARKER GEOMETRIES TO BE INCLUDED IN THE QC CHECK ========
  % The current defined geometries are set to the variables used in this paper (e.g., Vicon wand and variables previously selected by DiMarco et al 2017: https://doi.org/10.1016/j.measurement.2016.01.008)
  % Please ammend the definitions to fit the object used for your quality check and/or the SP marker model used to process the data.
  
  % Inter-marker distances ------------------------------------------------
  Distances.BE.PrimaryMarker = 'B';
  Distances.BE.SecondaryMarker = 'E';
  Distances.BE.KnownDistance = 240;
  
  Distances.BC.PrimaryMarker = 'B';
  Distances.BC.SecondaryMarker = 'C';
  Distances.BC.KnownDistance = 80;
  
  % Inter-marker angles ---------------------------------------------------
  Angles.A.OriginMarker = 'B';
  Angles.A.HorizontalAxisMarker = 'A';
  Angles.A.VerticalAxisMarker = 'E';
  Angles.A.KnownAngle = 90;
  
  Angles.C.OriginMarker = 'B';
  Angles.C.HorizontalAxisMarker = 'C';
  Angles.C.VerticalAxisMarker = 'E';
  Angles.C.KnownAngle = 90;
  
  %% DEFINE TOOLBOX TO USE ================================================
  
  QCToolbox = Paper_SPCheck_ToolBox;
  
  %% NAVIGATE TO QC CHECK FOLDER ==========================================
  
  Origin = uigetdir('C:\'); % Edit this to your main directory i.e. desktop or main folder where qualty control check data is.

  if Origin == 0
	 return; % If the folder doesn't exist then the script will end here
  end
  
  
  %% CHECK IF THE STATIC, DYNAMIC OR BOTH ARE MISSING AND NOTIFY THE USER.
  %  IF MORE THAN ONE C3D FILE FOR EITHER TASK, ASK USER TO SELECT CORRECT TRIAL.
    
  [Selected_Static,Selected_Dynamic] = QCToolbox.CheckCorrectTrials (Origin, StaticTrial_Filename, DynamicTrial_Filename);
  
  
  %% QUANTIFY RANDOM ERRORS FROM STATIC TRIAL =============================
  % Based on quantification in materials and methods seciton of paper.
  
  [Distances, Angles] = QCToolbox.QuantifyExpandedUncertainty(Selected_Static,Distances,Angles); 
  
  %% QUANTIFY SYSTEMATIC ERRORS FROM DYNAMIC TRIAL ========================
  % Based on quantification in materials and methods seciton of paper.
  
  [Distances, Angles] = QCToolbox.QuantifyRMSE(Selected_Dynamic,Distances,Angles); 
  
  %% GENERATE REPORT FOR QUALITY CONTROL CHECK ============================
  % Minimal formatting has been added to this report to allow the user to edit/add to.
  
  QCToolbox.CreateQCCheckReport(Distances,Angles); 
    
     
end

